Example gallery
===============

The examples below show some common use cases for SplineBox.
Feel free to submit example use cases via `GitHub Issues <https://github.com/EPFL-Center-for-Imaging/splinebox/issues/new>`_ or a pull request if you'd like them to be featured on our documentation website!
